<?php

namespace Litecms\Maintenance\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Maintenance\Actions\ContractAction;
use Litecms\Maintenance\Http\Requests\ContractActionRequest;
use Litecms\Maintenance\Http\Resources\ContractResource;
use Litecms\Maintenance\Models\Contract;

/**
 * Admin web controller class.
 */
class ContractActionController extends BaseController
{

    /**
     * Action controller function for contract.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ContractActionRequest $request, Contract $contract, $action)
    {
        try {
            $request = $request->all();
            $contract = ContractAction::run($action, $contract, $request);

            $data = new ContractResource($contract);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('maintenance::contract.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('maintenance/contract/' . $contract->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('maintenance/contract/' . $contract->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
