<?php

namespace Litecms\Maintenance\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Litecms\Maintenance\Http\Requests\ContractActionsRequest;
use Litecms\Maintenance\Actions\ContractActions;

/**
 * Admin web controller class.
 */
class ContractActionsController extends BaseController
{

    /**
     * Action controller function for contract.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ContractActionsRequest $request, $action)
    {
        try {
            $contract = ContractActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('maintenance::contract.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('maintenance/contract/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('maintenance/contract/' . $action))
                ->redirect();
        }
    }
}
