<?php

namespace Litecms\Maintenance\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Litecms\Maintenance\Http\Resources\MaintenanceResource;
use Litecms\Maintenance\Http\Resources\MaintenancesCollection;
use Litecms\Maintenance\Scopes\ContractPublicScope;
use Litecms\Maintenance\Models\Contract;

class ContractPublicController extends BaseController
{

    /**
     * Show contract's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Contract::pushScope(new RequestScope())
            ->pushScope(new ContractPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $contracts = new ContractsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('maintenance::contract.names'))
            ->view('maintenance::public.contract.index')
            ->data(compact('contracts', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show contract.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Contract::findBySlug($slug);
        $data = new ContractResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('maintenance::contract.name'))
            ->view('maintenance::public.contract.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
