<?php

namespace Litecms\Maintenance\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Maintenance\Actions\ContractReport;
use Litecms\Maintenance\Http\Requests\ContractReportRequest;

/**
 * Admin web controller class.
 */
class ContractReportController extends BaseController
{
    /**
     * Action controller function for contract.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ContractReportRequest $request, $report)
    {
        try {
        
            $this->model = app(Contract::class);
            $data = ContractReport::run($request, $report);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('maintenance::contract.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('maintenance/contract/' . $report))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('maintenance/contract/' . $report))
                ->redirect();
        }
    }
}
