<?php

namespace Litecms\Maintenance\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Maintenance\Actions\ProposalAction;
use Litecms\Maintenance\Http\Requests\ProposalActionRequest;
use Litecms\Maintenance\Http\Resources\ProposalResource;
use Litecms\Maintenance\Models\Proposal;

/**
 * Admin web controller class.
 */
class ProposalActionController extends BaseController
{

    /**
     * Action controller function for proposal.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ProposalActionRequest $request, Proposal $proposal, $action)
    {
        try {
            $request = $request->all();
            $proposal = ProposalAction::run($action, $proposal, $request);

            $data = new ProposalResource($proposal);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('maintenance::proposal.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('maintenance/proposal/' . $proposal->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('maintenance/proposal/' . $proposal->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
