<?php

namespace Litecms\Maintenance\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Litecms\Maintenance\Http\Resources\MaintenanceResource;
use Litecms\Maintenance\Http\Resources\MaintenancesCollection;
use Litecms\Maintenance\Scopes\ProposalPublicScope;
use Litecms\Maintenance\Models\Proposal;

class ProposalPublicController extends BaseController
{

    /**
     * Show proposal's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Proposal::pushScope(new RequestScope())
            ->pushScope(new ProposalPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $proposals = new ProposalsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('maintenance::proposal.names'))
            ->view('maintenance::public.proposal.index')
            ->data(compact('proposals', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show proposal.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Proposal::findBySlug($slug);
        $data = new ProposalResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('maintenance::proposal.name'))
            ->view('maintenance::public.proposal.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
