<?php

namespace Litecms\Maintenance\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Maintenance\Actions\VendorAction;
use Litecms\Maintenance\Http\Requests\VendorActionRequest;
use Litecms\Maintenance\Http\Resources\VendorResource;
use Litecms\Maintenance\Models\Vendor;

/**
 * Admin web controller class.
 */
class VendorActionController extends BaseController
{

    /**
     * Action controller function for vendor.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(VendorActionRequest $request, Vendor $vendor, $action)
    {
        try {
            $request = $request->all();
            $vendor = VendorAction::run($action, $vendor, $request);

            $data = new VendorResource($vendor);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('maintenance::vendor.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('maintenance/vendor/' . $vendor->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('maintenance/vendor/' . $vendor->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
