<?php

namespace Litecms\Maintenance\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Litecms\Maintenance\Http\Requests\VendorActionsRequest;
use Litecms\Maintenance\Actions\VendorActions;

/**
 * Admin web controller class.
 */
class VendorActionsController extends BaseController
{

    /**
     * Action controller function for vendor.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(VendorActionsRequest $request, $action)
    {
        try {
            $vendor = VendorActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('maintenance::vendor.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('maintenance/vendor/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('maintenance/vendor/' . $action))
                ->redirect();
        }
    }
}
