<?php

namespace Litecms\Maintenance\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Maintenance\Actions\WorkorderAction;
use Litecms\Maintenance\Http\Requests\WorkorderActionRequest;
use Litecms\Maintenance\Http\Resources\WorkorderResource;
use Litecms\Maintenance\Models\Workorder;

/**
 * Admin web controller class.
 */
class WorkorderActionController extends BaseController
{

    /**
     * Action controller function for workorder.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(WorkorderActionRequest $request, Workorder $workorder, $action)
    {
        try {
            $request = $request->all();
            $workorder = WorkorderAction::run($action, $workorder, $request);

            $data = new WorkorderResource($workorder);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('maintenance::workorder.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('maintenance/workorder/' . $workorder->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('maintenance/workorder/' . $workorder->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
