<?php

namespace Litecms\Maintenance\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Litecms\Maintenance\Http\Requests\WorkorderActionsRequest;
use Litecms\Maintenance\Actions\WorkorderActions;

/**
 * Admin web controller class.
 */
class WorkorderActionsController extends BaseController
{

    /**
     * Action controller function for workorder.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(WorkorderActionsRequest $request, $action)
    {
        try {
            $workorder = WorkorderActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('maintenance::workorder.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('maintenance/workorder/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('maintenance/workorder/' . $action))
                ->redirect();
        }
    }
}
