<?php

namespace Litecms\Maintenance\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Maintenance\Actions\WorkorderReport;
use Litecms\Maintenance\Http\Requests\WorkorderReportRequest;

/**
 * Admin web controller class.
 */
class WorkorderReportController extends BaseController
{
    /**
     * Action controller function for workorder.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(WorkorderReportRequest $request, $report)
    {
        try {
        
            $this->model = app(Workorder::class);
            $data = WorkorderReport::run($request, $report);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('maintenance::workorder.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('maintenance/workorder/' . $report))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('maintenance/workorder/' . $report))
                ->redirect();
        }
    }
}
