<?php

namespace Litecms\Maintenance\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Maintenance\Events\ContractAction as ContractActionEvent;
use Litecms\Maintenance\Notifications\ContractAction as ContractActionNotification;
use Litepie\Actions\Concerns\AsAction;

class ContractAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the ContractActionEvent.
     *
     * @param   ContractActionEvent  $event
     * @return mixed
     */
    public function handle(ContractActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $contract.
     *
     * @param   ContractActionEvent  $event
     * @return void
     */
    public function create(ContractActionEvent $event)
    {
        $client = $event->contract->client;
        Notification::send($client, new ContractActionNotification($event));
    }

    /**
     * Handle the ContractActionEvent as a listener.
     *
     * @param   ContractActionEvent  $event
     * @return mixed
     */
    public function asListener(ContractActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   ContractActionEvent  $event
     * @return bool
     */
    private function isAllowed(ContractActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
