<?php

namespace Litecms\Maintenance\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Maintenance\Events\ContractWorkflow as ContractWorkflowEvent;
use Litecms\Maintenance\Notifications\ContractWorkflow as ContractWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class ContractWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(ContractWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $contract is submitted.
     *
     * @param ContractWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(ContractWorkflowEvent $event)
    {
        $client = $event->contract->client;
        Notification::send($client, new ContractWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $contract is published.
     *
     * @param ContractWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(ContractWorkflowEvent $event)
    {
        $client = $event->contract->client;
        Notification::send($client, new ContractWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $contract is approved.
     *
     * @param ContractWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(ContractWorkflowEvent $event)
    {
        $client = $event->contract->client;
        Notification::send($client, new ContractWorkflowNotification($event));
    }

    /**
     * Handles the $contract workflow event as a listener.
     *
     * @param ContractWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(ContractWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
