<?php

namespace Litecms\Maintenance\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Maintenance\Events\ProposalWorkflow as ProposalWorkflowEvent;
use Litecms\Maintenance\Notifications\ProposalWorkflow as ProposalWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class ProposalWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(ProposalWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $proposal is submitted.
     *
     * @param ProposalWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(ProposalWorkflowEvent $event)
    {
        $client = $event->proposal->client;
        Notification::send($client, new ProposalWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $proposal is published.
     *
     * @param ProposalWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(ProposalWorkflowEvent $event)
    {
        $client = $event->proposal->client;
        Notification::send($client, new ProposalWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $proposal is approved.
     *
     * @param ProposalWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(ProposalWorkflowEvent $event)
    {
        $client = $event->proposal->client;
        Notification::send($client, new ProposalWorkflowNotification($event));
    }

    /**
     * Handles the $proposal workflow event as a listener.
     *
     * @param ProposalWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(ProposalWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
