<?php

namespace Litecms\Maintenance\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Maintenance\Events\VendorAction as VendorActionEvent;
use Litecms\Maintenance\Notifications\VendorAction as VendorActionNotification;
use Litepie\Actions\Concerns\AsAction;

class VendorAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the VendorActionEvent.
     *
     * @param   VendorActionEvent  $event
     * @return mixed
     */
    public function handle(VendorActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $vendor.
     *
     * @param   VendorActionEvent  $event
     * @return void
     */
    public function create(VendorActionEvent $event)
    {
        $client = $event->vendor->client;
        Notification::send($client, new VendorActionNotification($event));
    }

    /**
     * Handle the VendorActionEvent as a listener.
     *
     * @param   VendorActionEvent  $event
     * @return mixed
     */
    public function asListener(VendorActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   VendorActionEvent  $event
     * @return bool
     */
    private function isAllowed(VendorActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
