<?php

namespace Litecms\Maintenance\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Maintenance\Events\WorkorderWorkflow as WorkorderWorkflowEvent;
use Litecms\Maintenance\Notifications\WorkorderWorkflow as WorkorderWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class WorkorderWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(WorkorderWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $workorder is submitted.
     *
     * @param WorkorderWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(WorkorderWorkflowEvent $event)
    {
        $client = $event->workorder->client;
        Notification::send($client, new WorkorderWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $workorder is published.
     *
     * @param WorkorderWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(WorkorderWorkflowEvent $event)
    {
        $client = $event->workorder->client;
        Notification::send($client, new WorkorderWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $workorder is approved.
     *
     * @param WorkorderWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(WorkorderWorkflowEvent $event)
    {
        $client = $event->workorder->client;
        Notification::send($client, new WorkorderWorkflowNotification($event));
    }

    /**
     * Handles the $workorder workflow event as a listener.
     *
     * @param WorkorderWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(WorkorderWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
