<?php
namespace Litecms\Maintenance\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Maintenance\Events\ContractAction as ContractActionEvent;
use Litecms\Maintenance\Models\Contract;

class ContractAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $contract;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param ContractActionEvent $contract
     */
    public function __construct(ContractActionEvent $contract)
    {
        $this->action = $event->action;
        $this->contract = $contract;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Contract Approved - ' . config('app.name'))
            ->view('maintenance::contract.email.action', ['data' => $this->contract]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
