<?php
namespace Litecms\Maintenance\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Maintenance\Events\ProposalAction as ProposalActionEvent;
use Litecms\Maintenance\Models\Proposal;

class ProposalAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $proposal;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param ProposalActionEvent $proposal
     */
    public function __construct(ProposalActionEvent $proposal)
    {
        $this->action = $event->action;
        $this->proposal = $proposal;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Proposal Approved - ' . config('app.name'))
            ->view('maintenance::proposal.email.action', ['data' => $this->proposal]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
