<?php
namespace Litecms\Maintenance\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Maintenance\Events\VendorAction as VendorActionEvent;
use Litecms\Maintenance\Models\Vendor;

class VendorAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $vendor;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param VendorActionEvent $vendor
     */
    public function __construct(VendorActionEvent $vendor)
    {
        $this->action = $event->action;
        $this->vendor = $vendor;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Vendor Approved - ' . config('app.name'))
            ->view('maintenance::vendor.email.action', ['data' => $this->vendor]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
