<?php
namespace Litecms\Maintenance\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Maintenance\Events\WorkorderAction as WorkorderActionEvent;
use Litecms\Maintenance\Models\Workorder;

class WorkorderAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $workorder;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param WorkorderActionEvent $workorder
     */
    public function __construct(WorkorderActionEvent $workorder)
    {
        $this->action = $event->action;
        $this->workorder = $workorder;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Workorder Approved - ' . config('app.name'))
            ->view('maintenance::workorder.email.action', ['data' => $this->workorder]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
