<?php

namespace Litecms\Maintenance\Policies;

use Litecms\Maintenance\Models\Contract;
use Litepie\User\Interfaces\UserPolicyInterface;

trait ContractAction
{

    /**
     * Determine if the given user can approve the given contract.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function copy(UserPolicyInterface $authUser, Contract $contract)
    {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('maintenance.contract.action.copy')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given contract.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    function empty(UserPolicyInterface $authUser, Contract $contract) {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('maintenance.contract.action.empty')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given contract.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function transfer(UserPolicyInterface $authUser, Contract $contract)
    {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('maintenance.contract.action.transfer')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given contract.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function delete(UserPolicyInterface $authUser, Contract $contract)
    {


        if ($authUser->canDo('maintenance.contract.action.delete')) {
            return true;
        }

        return false;
    }


}
