<?php

namespace Litecms\Maintenance\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Maintenance\Models\Proposal;

class ProposalPolicy
{

    use ProposalAction;
    use ProposalReport;
    use ProposalWorkflow;

    /**
     * Determine if the given user can view the proposal.
     *
     * @param UserPolicyInterface $authUser
     * @param Proposal $proposal
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Proposal $proposal)
    {
        if ($authUser->canDo('maintenance.proposal.view') && $authUser->isAdmin()) {
            return true;
        }

        return $proposal->user_id == user_id() && $proposal->user_type == user_type();
    }

    /**
     * Determine if the given user can create a proposal.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('maintenance.proposal.create');
    }

    /**
     * Determine if the given user can update the given proposal.
     *
     * @param UserPolicyInterface $authUser
     * @param Proposal $proposal
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Proposal $proposal)
    {
        if ($authUser->canDo('maintenance.proposal.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $proposal->user_id == user_id() && $proposal->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given proposal.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Proposal $proposal)
    {
        return $proposal->user_id == user_id() && $proposal->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given proposal.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Proposal $proposal)
    {
        if ($authUser->canDo('maintenance.proposal.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given proposal.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Proposal $proposal)
    {
        if ($authUser->canDo('maintenance.proposal.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
