<?php

namespace Litecms\Maintenance\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Maintenance\Models\Vendor;

class VendorPolicy
{

    use VendorAction;

    /**
     * Determine if the given user can view the vendor.
     *
     * @param UserPolicyInterface $authUser
     * @param Vendor $vendor
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Vendor $vendor)
    {
        if ($authUser->canDo('maintenance.vendor.view') && $authUser->isAdmin()) {
            return true;
        }

        return $vendor->user_id == user_id() && $vendor->user_type == user_type();
    }

    /**
     * Determine if the given user can create a vendor.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('maintenance.vendor.create');
    }

    /**
     * Determine if the given user can update the given vendor.
     *
     * @param UserPolicyInterface $authUser
     * @param Vendor $vendor
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Vendor $vendor)
    {
        if ($authUser->canDo('maintenance.vendor.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $vendor->user_id == user_id() && $vendor->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given vendor.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Vendor $vendor)
    {
        return $vendor->user_id == user_id() && $vendor->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given vendor.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Vendor $vendor)
    {
        if ($authUser->canDo('maintenance.vendor.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given vendor.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Vendor $vendor)
    {
        if ($authUser->canDo('maintenance.vendor.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
