<?php

namespace Litecms\Maintenance\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Maintenance\Models\Workorder;

class WorkorderPolicy
{

    use WorkorderAction;
    use WorkorderReport;
    use WorkorderWorkflow;

    /**
     * Determine if the given user can view the workorder.
     *
     * @param UserPolicyInterface $authUser
     * @param Workorder $workorder
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Workorder $workorder)
    {
        if ($authUser->canDo('maintenance.workorder.view') && $authUser->isAdmin()) {
            return true;
        }

        return $workorder->user_id == user_id() && $workorder->user_type == user_type();
    }

    /**
     * Determine if the given user can create a workorder.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('maintenance.workorder.create');
    }

    /**
     * Determine if the given user can update the given workorder.
     *
     * @param UserPolicyInterface $authUser
     * @param Workorder $workorder
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Workorder $workorder)
    {
        if ($authUser->canDo('maintenance.workorder.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $workorder->user_id == user_id() && $workorder->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given workorder.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Workorder $workorder)
    {
        return $workorder->user_id == user_id() && $workorder->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given workorder.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Workorder $workorder)
    {
        if ($authUser->canDo('maintenance.workorder.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given workorder.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Workorder $workorder)
    {
        if ($authUser->canDo('maintenance.workorder.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
